@@ -29,7 +29,7 @@
 #include "gupnp-dlna-profile.h"
 
 #define GST_CAPS_NULL_NAME "NULL"
-#define DLNA_DATA_DIR DATA_DIR \
+#define DLNA_DATA_DIR DATA_DIR                              \
         G_DIR_SEPARATOR_S "dlna-profiles" G_DIR_SEPARATOR_S
 
 static gboolean
@@ -54,21 +54,21 @@ merge_caps (GstCaps *caps1, GstCaps *caps2)
         /* If one of the caps GST_CAPS_ANY, gst_caps_merge will result in a
          * GST_CAPS_ANY, which might not be correct for us */
         if (!gst_caps_is_any (caps1) && !gst_caps_is_any (caps2)) {
-          any = TRUE;
-          gst_caps_merge (caps1, gst_caps_copy (caps2));
-          gst_caps_do_simplify (caps1);
+                any = TRUE;
+                gst_caps_merge (caps1, gst_caps_copy (caps2));
+                gst_caps_do_simplify (caps1);
         }
 
         ret = gst_caps_make_writable (caps1);
         st1 = gst_caps_get_structure (ret, 0);
         if (gst_caps_get_size (caps1) == 2)
-          /* Non-merged fields were copied to a second structure in caps1 at
-           * gst_merge_caps() time */
-          st2 = gst_caps_get_structure (ret, 1);
+                /* Non-merged fields were copied to a second structure in caps
+                 * at gst_merge_caps() time */
+                st2 = gst_caps_get_structure (ret, 1);
         else
-          /* Either one of the caps was GST_CAPS_ANY, or there were no
-           * unmerged fields */
-          st2 = gst_caps_get_structure (caps2, 0);
+                /* Either one of the caps was GST_CAPS_ANY, or there were no
+                 * unmerged fields */
+                st2 = gst_caps_get_structure (caps2, 0);
 
         /* If caps1 has a name, we retain it. If not, and caps2 does, caps1
          * gets caps2's name. */
@@ -82,10 +82,10 @@ merge_caps (GstCaps *caps1, GstCaps *caps2)
         /* We now walk over the structures and append any fields that are in
          * caps2 but not in caps1. */
         if (any || gst_caps_get_size (caps1) == 2)
-          gst_structure_foreach (st2, copy_func, st1);
+                gst_structure_foreach (st2, copy_func, st1);
 
         if (gst_caps_get_size (caps1) == 2)
-          gst_caps_remove_structure (ret, 1);
+                gst_caps_remove_structure (ret, 1);
 
         return ret;
 }
@@ -133,6 +133,7 @@ get_value (xmlTextReaderPtr reader)
                     xmlStrEqual (tag, BAD_CAST ("value"))) {
                         /* </value> */
                         xmlFree (tag);
+
                         break;
                 }
 
@@ -142,6 +143,7 @@ get_value (xmlTextReaderPtr reader)
 
         if (!value)
                 g_warning ("Empty <value>s are illegal");
+
         return value;
 }
 
@@ -160,7 +162,7 @@ dlna_encoding_profile_add_stream (GstEncodingProfile       *profile,
         /* Try to merge with an existing stream profile of the same type */
         for (i = profile->encodingprofiles; i; i = i->next) {
                 GstStreamEncodingProfile *cur =
-                                        (GstStreamEncodingProfile *) i->data;
+                        (GstStreamEncodingProfile *) i->data;
 
                 if (cur->type != stream_profile->type)
                         continue;
@@ -181,7 +183,8 @@ done:
         return;
 }
 
-static void process_range (xmlTextReaderPtr reader, GString *caps_str)
+static void
+process_range (xmlTextReaderPtr reader, GString *caps_str)
 {
         xmlChar *min, *max;
 
@@ -215,13 +218,13 @@ process_field (xmlTextReaderPtr reader,
         if (used) {
                 if ((relaxed_mode == FALSE) &&
                     xmlStrEqual (used, BAD_CAST ("in-relaxed"))) {
-                        xmlFree (used);
                         skip = TRUE;
                 } else if ((relaxed_mode == TRUE) &&
                            (xmlStrEqual (used, BAD_CAST ("in-strict")))) {
-                        xmlFree (used);
                         skip = TRUE;
                 }
+
+                xmlFree (used);
         }
 
         name = xmlTextReaderGetAttribute (reader, BAD_CAST ("name"));
@@ -240,6 +243,7 @@ process_field (xmlTextReaderPtr reader,
          * field - we will be prepending the restriction name to this string */
         if (!skip)
                 g_string_append_printf (caps_str, ", %s = (%s) ", name, type);
+
         xmlFree (name);
         xmlFree (type);
 
@@ -289,16 +293,19 @@ process_field (xmlTextReaderPtr reader,
 
         if (g_list_length (values) == 1)
                 /* Single value */
-                g_string_append_printf (caps_str, "%s",
+                g_string_append_printf (caps_str,
+                                        "%s",
                                         (xmlChar *) values->data);
         else if (g_list_length (values) > 1) {
                 /* Multiple values */
                 GList *tmp = values->next;
-                g_string_append_printf (caps_str, "{ %s",
+                g_string_append_printf (caps_str,
+                                        "{ %s",
                                         (xmlChar *) values->data);
 
                 do {
-                        g_string_append_printf (caps_str, ", %s",
+                        g_string_append_printf (caps_str,
+                                                ", %s",
                                                 (xmlChar *) tmp->data);
                 } while ((tmp = tmp->next) != NULL);
 
@@ -350,14 +357,12 @@ process_parent (xmlTextReaderPtr reader,
 
         xmlFree (parent);
         xmlFree (used);
+
         return gst_stream_encoding_profile_copy (profile);
 }
 
 static GstStreamEncodingProfile *
-process_restriction (xmlTextReaderPtr reader,
-                     GHashTable       *restrictions,
-                     gboolean         relaxed_mode,
-                     gboolean         extended_mode)
+process_restriction (xmlTextReaderPtr reader, GUPnPDLNALoadState *data)
 {
         GstStreamEncodingProfile *stream_profile = NULL;
         GstEncodingProfileType type;
@@ -374,10 +379,10 @@ process_restriction (xmlTextReaderPtr reader,
          */
         used = xmlTextReaderGetAttribute (reader, BAD_CAST ("used"));
         if (used) {
-                if ((relaxed_mode == FALSE) &&
+                if ((data->relaxed_mode == FALSE) &&
                     xmlStrEqual (used, BAD_CAST ("in-relaxed"))) {
                         skip = TRUE;
-                } else if ((relaxed_mode == TRUE) &&
+                } else if ((data->relaxed_mode == TRUE) &&
                            (xmlStrEqual (used, BAD_CAST ("in-strict")))) {
                         skip = TRUE;
                 }
@@ -406,8 +411,8 @@ process_restriction (xmlTextReaderPtr reader,
                                 /* <field> */
                                 xmlChar *field;
 
-                                field = xmlTextReaderGetAttribute (reader,
-                                        BAD_CAST ("name"));
+                                field = xmlTextReaderGetAttribute
+                                        (reader, BAD_CAST ("name"));
 
                                 /* We handle the "name" field specially - if
                                  * present, it is the caps name */
@@ -416,17 +421,17 @@ process_restriction (xmlTextReaderPtr reader,
                                 else
                                         process_field (reader,
                                                        caps_str,
-                                                       relaxed_mode,
-                                                       extended_mode);
+                                                       data->relaxed_mode,
+                                                       data->extended_mode);
 
                                 xmlFree (field);
                         } else if (xmlStrEqual (tag, BAD_CAST ("parent"))) {
                                 /* <parent> */
                                 GstStreamEncodingProfile *profile =
                                         process_parent (reader,
-                                                        restrictions,
-                                                        relaxed_mode,
-                                                        extended_mode);
+                                                        data->restrictions,
+                                                        data->relaxed_mode,
+                                                        data->extended_mode);
 
                                 if (profile)
                                         /* Collect parents in a list - we'll
@@ -501,7 +506,7 @@ process_restriction (xmlTextReaderPtr reader,
                  * profile */
                 GstStreamEncodingProfile *tmp =
                         gst_stream_encoding_profile_copy (stream_profile);
-                g_hash_table_insert (restrictions, id, tmp);
+                g_hash_table_insert (data->restrictions, id, tmp);
         }
 
 out:
@@ -512,14 +517,12 @@ out:
                 gst_caps_unref (caps);
         if (parents)
                 g_list_free (parents);
+
         return stream_profile;
 }
 
 static void
-process_restrictions (xmlTextReaderPtr reader,
-                      GHashTable       *restrictions,
-                      gboolean         relaxed_mode,
-                      gboolean         extended_mode)
+process_restrictions (xmlTextReaderPtr reader, GUPnPDLNALoadState *data)
 {
         /* While we use a GstStreamEncodingProfile to store restrictions here,
          * this is not how they are finally used. This is just a convenient
@@ -542,9 +545,7 @@ process_restrictions (xmlTextReaderPtr reader,
                                 /* <restriction> */
                                 GstStreamEncodingProfile *stream =
                                         process_restriction (reader,
-                                                             restrictions,
-                                                             relaxed_mode,
-                                                             extended_mode);
+                                                             data);
                                 gst_stream_encoding_profile_free (stream);
                         }
 
@@ -616,9 +617,7 @@ process_dlna_profile (xmlTextReaderPtr   reader,
                         if (xmlStrEqual (tag, BAD_CAST ("restriction"))) {
                                 stream_profile =
                                         process_restriction (reader,
-                                                             data->restrictions,
-                                                             data->relaxed_mode,
-                                                             data->extended_mode);
+                                                             data);
                         } else if (xmlStrEqual (tag, BAD_CAST ("parent"))) {
                                 stream_profile =
                                         process_parent (reader,
@@ -631,9 +630,8 @@ process_dlna_profile (xmlTextReaderPtr   reader,
                                 break;
 
                         if (stream_profile->type ==
-                                        GST_ENCODING_PROFILE_UNKNOWN) {
-                                format = gst_caps_copy (
-                                                stream_profile->format);
+                            GST_ENCODING_PROFILE_UNKNOWN) {
+                                format = gst_caps_copy (stream_profile->format);
                                 gst_stream_encoding_profile_free (stream_profile);
                         } else {
                                 stream_profiles =
@@ -718,8 +716,7 @@ out:
 }
 
 static GList *
-process_include (xmlTextReaderPtr   reader,
-                 GUPnPDLNALoadState *data)
+process_include (xmlTextReaderPtr reader, GUPnPDLNALoadState *data)
 {
         xmlChar *path;
         GList *ret;
@@ -831,9 +828,7 @@ gupnp_dlna_load_profiles_from_file (const char         *file_name,
                                         BAD_CAST ("restrictions"))) {
                                         /* <restrictions> */
                                         process_restrictions (reader,
-                                                              data->restrictions,
-                                                              data->relaxed_mode,
-                                                              data->extended_mode);
+                                                              data);
                                 } else if (xmlStrEqual (tag,
                                         BAD_CAST ("dlna-profile"))) {
                                         /* <dlna-profile> */
@@ -859,26 +854,28 @@ gupnp_dlna_load_profiles_from_file (const char         *file_name,
 
 out:
         g_free (path);
+
         return profiles;
 }
 
 GList *
-gupnp_dlna_load_profiles_from_dir (gchar              *profile_dir,
-                                   GUPnPDLNALoadState *data)
+gupnp_dlna_load_profiles_from_dir (gchar *profile_dir, GUPnPDLNALoadState *data)
 {
         GDir *dir;
+
         data->restrictions =
                 g_hash_table_new_full (g_str_hash,
                                        g_str_equal,
                                        (GDestroyNotify) xmlFree,
                                        (GDestroyNotify)
-                                        gst_stream_encoding_profile_free);
+                                       gst_stream_encoding_profile_free);
         data->profile_ids =
                 g_hash_table_new_full (g_str_hash,
                                        g_str_equal,
                                        (GDestroyNotify) xmlFree,
                                        (GDestroyNotify)
-                                        gst_encoding_profile_free);
+                                       gst_encoding_profile_free);
+
         GList *profiles = NULL;
 
         if ((dir = g_dir_open (profile_dir, 0, NULL))) {
@@ -906,6 +903,7 @@ gupnp_dlna_load_profiles_from_dir (gchar              *profile_dir,
 
         g_hash_table_unref (data->restrictions);
         g_hash_table_unref (data->profile_ids);
+
         return profiles;
 }
 
@@ -916,7 +914,7 @@ gupnp_dlna_load_profiles_from_disk (gboolean relaxed_mode,
         GUPnPDLNALoadState *load_data;
         GList *ret, *i;
 
-        load_data = g_new (GUPnPDLNALoadState, 1);
+        load_data = g_new0 (GUPnPDLNALoadState, 1);
 
         if (load_data) {
                 load_data->files_hash = g_hash_table_new_full (g_str_hash,
@@ -936,7 +934,8 @@ gupnp_dlna_load_profiles_from_disk (gboolean relaxed_mode,
         while (i) {
                 GUPnPDLNAProfile *profile = i->data;
                 const GstEncodingProfile *enc_profile =
-                                        gupnp_dlna_profile_get_encoding_profile (profile);
+                                        gupnp_dlna_profile_get_encoding_profile
+                                                  (profile);
                 GList *tmp = g_list_next (i);
 
                 if (enc_profile->name[0] == '\0') {
@@ -950,5 +949,6 @@ gupnp_dlna_load_profiles_from_disk (gboolean relaxed_mode,
         g_hash_table_unref (load_data->files_hash);
         g_free (load_data);
         load_data = NULL;
+
         return ret;
 }
